#
# Autogenerated by Thrift Compiler (0.9.1)
#
# DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
#
#  options string: py
#

from thrift.Thrift import TType, TMessageType, TException, TApplicationException
from ttypes import *

TYPE_STRING = "string"
TYPE_TEXT = "text"
TYPE_bool = "boolean"
TYPE_INTEGER = "integer"
TYPE_ENUM = "enum"
TYPE_FILE = "file"
TYPE_INPUT_COLLECTION = "inputCollection"
TYPE_OUTPUT_COLLECTION = "outputCollection"
TYPE_SECURITY_LABEL_PARSER = "securityLabelParser"
TYPE_COLLECTION_FIELD = "collectionField"
TYPE_COLLECTION_MULTIPLE_FIELD = "collectionMultipleField"
